<?php

namespace App\Admin\Controllers;

use App\Models\Blog;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;
use Illuminate\Support\Str;

class BlogController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = 'Blog';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Blog());

        $grid->column('id', __('Id'));
        // $grid->column('type', __('Type'));
        // $grid->column('category', __('Category'));
        $grid->column('slug', __('Slug'));
        $grid->column('short_title', __('Short title'));
        $grid->column('title', __('Title'))->display(function ($title) {
            return Str::limit($title, 20);
        });
        $grid->column('Excerpt', __('Excerpt'))->display(function ($excerpt) {
            return Str::limit($excerpt, 20);
        });
        // $grid->column('content', __('Content'));
        $grid->column('image', __('Image'));
        // $grid->column('youtube_link', __('Youtube link'));
        // $grid->column('time', __('Time'));
        // $grid->column('action_title', __('Action title'));
        // $grid->column('action_route_name', __('Action route name'));
        // $grid->column('action_url', __('Action url'));
        $grid->column('seo_title', __('Seo title'));
        $grid->column('seo_description', __('Seo description'));
        $grid->column('show_date', __('Show date'))->display(function ($show_date) {
            return date('d-M-Y g:i A', strtotime($show_date));
        });
        $grid->column('status', __('Status'));
        $grid->column('created_at', __('Created at'))->display(function ($created_at) {
            return date('d-M-Y g:i A', strtotime($created_at));
        });
        // $grid->column('updated_at', __('Updated at'));
        // $grid->column('created_by', __('Created by'));
        // $grid->column('updated_by', __('Updated by'));
        // $grid->column('deleted_at', __('Deleted at'));

        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Blog::findOrFail($id));

        $show->field('id', __('Id'));
        // $show->field('type', __('Type'));
        // $show->field('category', __('Category'));
        $show->field('slug', __('Slug'));
        $show->field('short_title', __('Short title'));
        $show->field('title', __('Title'));
        $show->field('Excerpt', __('Excerpt'));
        // $show->field('content', __('Content'));
        $show->field('image', __('Image'));
        // $show->field('youtube_link', __('Youtube link'));
        // $show->field('time', __('Time'));
        // $show->field('action_title', __('Action title'));
        // $show->field('action_route_name', __('Action route name'));
        // $show->field('action_url', __('Action url'));
        $show->field('seo_title', __('Seo title'));
        $show->field('seo_description', __('Seo description'));
        $show->field('show_date', __('Show date'));
        $show->field('status', __('Status'));
        $show->field('created_at', __('Created at'));
        // $show->field('updated_at', __('Updated at'));
        // $show->field('created_by', __('Created by'));
        // $show->field('updated_by', __('Updated by'));
        // $show->field('deleted_at', __('Deleted at'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Blog());

        // $form->number('type', __('Type'))->default(1);
        // $form->number('category', __('Category'))->default(1);
        $form->text('slug', __('Slug'))->required();
        $form->text('short_title', __('Short title'))->required();
        $form->text('title', __('Title'))->required();
        $form->text('Excerpt', __('Excerpt'))->required();
        $form->ckeditor('content', __('Content'))->required();
        $form->image('image', __('Image'))->move('images/blogs')->uniqueName()->required();
        // $form->text('youtube_link', __('Youtube link'));
        // $form->text('time', __('Time'));
        // $form->text('action_title', __('Action title'));
        // $form->text('action_route_name', __('Action route name'));
        // $form->text('action_url', __('Action url'));
        $form->text('seo_title', __('Seo title'));
        $form->text('seo_description', __('Seo description'));
        $form->text('seo_keywords', __('Seo Keywords'));
        $form->datetime('show_date', __('Show date'))->default(date('Y-m-d H:i:s'));
        $form->switch('status', __('Status'))->default(1);

        return $form;
    }
}
