<?php

namespace App\Admin\Controllers;

use App\Models\Contactus;
use App\Models\User;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Facades\Admin;

use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;
use Encore\Admin\Layout\Column;
use Encore\Admin\Layout\Content;
use Encore\Admin\Layout\Row;

class ContactusController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = 'Enquiries';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Contactus());
        $grid->model()->where('formType','<>', '1');
        $grid->model()->orderBy('id', 'desc');

        $form_type = ['1' => 'Appointment', '2' => 'Enquiry', 3 => 'Contact Us'];
        $grid->column('id', __('Id'));
        $grid->column('formType', __('Form Type'))->using($form_type);
        $grid->column('userName', __('User Name'));
        $grid->column('userEmail', __('User Email'));
        $grid->column('userMobile', __('User Mobile'));
        $grid->column('subject', __('Subject'));
        $grid->column('message', __('Message'));
        $grid->column('appointDate', __('Appointment Date'));
        $grid->column('created_at', __('Created at'))->display(function ($created_at) {
            return date('d-M-Y g:i A', strtotime($created_at));
        });
        $grid->disableCreateButton();
        $grid->actions(function ($actions) {
            $actions->disableDelete();
            $actions->disableEdit();
        });
        return $grid;
    }
    public function appointment(Content $content)
    {
        $content
            ->title('Appointment')
            ->description('Appointment enquiry list')
            ->row(function (Row $row) {
                $row->column(12, function (Column $column) {
                    $grid = new Grid(new Contactus());
                    $grid->model()->where('formType', '1');
                    $grid->model()->orderBy('id', 'desc');

                    $form_type = ['1' => 'Appointment', '2' => 'Enquiry', 3 => 'Contact Us'];
                    $grid->column('id', __('Id'));
                    $grid->column('formType', __('Form Type'))->using($form_type);
                    $grid->column('userName', __('User Name'));
                    $grid->column('userEmail', __('User Email'));
                    $grid->column('userMobile', __('User Mobile'));
                    $grid->column('subject', __('Subject'));
                    $grid->column('message', __('Message'));
                    $grid->column('appointDate', __('Appointment Date'));
                    $grid->column('created_at', __('Created at'))->display(function ($created_at) {
                        return date('d-M-Y g:i A', strtotime($created_at));
                    });
                    $grid->disableCreateButton();
                    $grid->actions(function ($actions) {
                        $actions->disableDelete();
                        $actions->disableEdit();
                    });
                    $column->append($grid);
                });
            });
        return $content;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Contactus::findOrFail($id));

        $form_type = ['1' => 'Appointment', '2' => 'Enquiry', 3 => 'Contact Us'];
        $show->field('formType', __('Form Type'))->using($form_type);
        $show->field('userName', __('User Name'));
        $show->field('userEmail', __('User Email'));
        $show->field('userMobile', __('User Mobile'));
        $show->field('subject', __('Subject'));
        $show->field('message', __('Message'));
        $show->field('appointDate', __('Appointment Date'));
        $show->field('created_at', __('Created at'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */

    protected function form()
    {
        $form = new Form(new Contactus());
        $form->disableEditingCheck();
        $form->disableCreatingCheck();
        $form->disableViewCheck();


        return $form;
    }


    public function destroy($id)
    {
        echo $id;
        die;
        Admin::form(Expenses::class, function (Form $form) {
            $form->number('status')->value(9);
        });
        if ($this->form()->update($id)) {
            return response()->json([
                'status'  => true,
                'message' => 'success',
            ]);
        }
    }
}
