<?php

namespace App\Http\Controllers;

use Mailjet\Resources;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    private $SENDER_EMAIL;
    private $SENDER_NAME;
    private $MAILJET_APIKEY;
    private $MAILJET_APISECRET;
    public function __construct() {
        $this->SENDER_EMAIL = $SENDER_EMAIL = env('MAIL_FROM_ADDRESS');
        $this->SENDER_CC_EMAIL = $SENDER_EMAIL = env('MAIL_CC_FROM_ADDRESS');
        $this->SENDER_CC_NAME = $SENDER_EMAIL = env('APP_NAME');
        $this->SENDER_NAME = $SENDER_NAME = env('MAIL_FROM_NAME');
        $this->MAILJET_APIKEY = $MAILJET_APIKEY = env('MAILJET_APIKEY');
        $this->MAILJET_APISECRET = $MAILJET_APISECRET = env('MAILJET_APISECRET');
        // $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function savecontact(Request $request)
    {
        $this->validate($request, [
            'g-recaptcha-response' => 'required|captcha',
        ]);
        
        $formtype = $request->formtype ?? 1;
        $username = $request->username ?? '';
        $useremail = $request->useremail ?? '';
        $userphone = $request->userphone ?? '';
        $subject = $request->subject ?? '';
        $message = $request->message ?? '';
        $appointdate = $request->appointdate ?? '';
        if ($username != '' && $useremail != '') {
            $insdata = [
                'formType' => $formtype,
                'userName' => $username,
                'userEmail' => $useremail,
                'userMobile' => $userphone,
                'subject' => $subject,
                'message' => $message,
                'status' => 1,
                'created_at' => date('Y-m-d H:i:s')
            ];
            if($appointdate!=''){
                $insdata['appointDate']=date('Y-m-d',strtotime($appointdate));
            }
            $msg = 'Appointment enquiry has been submited successfully.';
            if ($formtype == '3') {
                $msg = 'Contact enquiry has been submited successfully.';
            }
            if ($formtype == '2') {
                $msg = 'Enquiry has been submited successfully.';
            }
            \DB::table('contactus')->insert($insdata);

            $mail_subject = "APPOINTMENT From SFTS LAB Website";
            if ($request->formtype == '2') {
                $mail_subject = "Enquiry From SFTS LAB Website";
            } elseif ($request->formtype == '3') {
                $mail_subject = "Contact enquiry From SFTS LAB Website";
            }

            $mail_html = "Dear Team,<br><br>Hi,You have received an " . $mail_subject . "<br><br>";
            $mail_html = $mail_html . "Name : " . $username . "<br>";
            $mail_html = $mail_html . "Email : " . $useremail . "<br>";
            $mail_html = $mail_html . "Mobile : " . $userphone . "<br>";
            if($subject!==''){
                $mail_html = $mail_html . "Subject : " . $subject . "<br>";
            }
            if($message!==''){
                $mail_html = $mail_html . "Message : " . $message . "<br>";
            }
            $mail_html = $mail_html . "Appoint date : " . date('Y-m-d', strtotime($appointdate)) . "<br><br>Best Regards<br>SFTS LAB";

            $mailresult=$this->mailConfig($mail_subject, $mail_html, '', '');
            
            return response()->json(
                [
                    'mailresult' => $mailresult,
                    'success' => true,
                    'message' => $msg,
                    'type' => 'success',
                    'formtype' => $formtype
                ]
            );
        }

        return response()->json(
            [
                'success' => false,
                'message' => 'Contact enquiry not inserted,Kindly try again later',
                'type' => 'danger'
            ]
        );
    }

    private function mailConfig($subject, $html, $email, $name) {

        $body = [
            'Messages' => [[
            'From' => ['Email' => $this->SENDER_EMAIL, 'Name' => $this->SENDER_NAME],
            'To' => [['Email' => $email, 'Name' => $name]],
            'Subject' => $subject,
            'HtmlPart' => $html,
                ]]
        ];

        $body_admin = [
            'Messages' => [[
            'From' => ['Email' => $this->SENDER_EMAIL, 'Name' => $this->SENDER_NAME],
            'To' => [['Email' => $this->SENDER_CC_EMAIL, 'Name' => $this->SENDER_CC_NAME]],
            'Subject' => $subject,
            'HtmlPart' => $html,
                ]]
        ];

        $result = $this->SendMail($body_admin);

//        self::SendMail($body_admin);

        return $result;
    }

    private function SendMail($body) {

//        print_r('<br>body : ');
//        print_r($body);

        $apikey = $this->MAILJET_APIKEY;
        $apisecret = $this->MAILJET_APISECRET;

        // print_r('<br>MAILJET_APIKEY : ' . $apikey . '<br>MAILJET_APISECRET : ' . $apisecret);

        $mj = new \Mailjet\Client($apikey, $apisecret, true, ['version' => 'v3.1']);

        $response = $mj->post(Resources::$Email, ['body' => $body]);

//        print_r('<br>getStatus : ');
//        print_r($response->getStatus());

        if ($response->success()) {
//            print_r('<br>getData : ');
//            print_r($response->getData());
            return $response->getData();
        }

        return 'Failed';
    }
}
